@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *     https://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -347,7 +347,7 @@ public class TestCombinedConfiguration {
      * Tests accessing properties if no configurations have been added.
      */
     @Test
-    void testAccessPropertyEmpty() {
+    public void testAccessPropertyEmpty() {
         assertFalse(config.containsKey(TEST_KEY));
         assertNull(config.getString("test.comment"));
         assertTrue(config.isEmpty());
@@ -357,7 +357,7 @@ public class TestCombinedConfiguration {
      * Tests accessing properties if multiple configurations have been added.
      */
     @Test
-    void testAccessPropertyMulti() {
+    public void testAccessPropertyMulti() {
         config.addConfiguration(setUpTestConfiguration());
         config.addConfiguration(setUpTestConfiguration(), null, "prefix1");
         config.addConfiguration(setUpTestConfiguration(), null, "prefix2");
@@ -372,7 +372,7 @@ public class TestCombinedConfiguration {
      * Tests adding a configuration (without further information).
      */
     @Test
-    void testAddConfiguration() {
+    public void testAddConfiguration() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c);
         checkAddConfig(c);
@@ -387,7 +387,7 @@ public class TestCombinedConfiguration {
      * Tests adding a configuration and specifying an at position.
      */
     @Test
-    void testAddConfigurationAt() {
+    public void testAddConfigurationAt() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, null, "my");
         checkAddConfig(c);
@@ -398,7 +398,7 @@ public class TestCombinedConfiguration {
      * Tests adding a configuration with a complex at position. Here the at path contains a dot, which must be escaped.
      */
     @Test
-    void testAddConfigurationComplexAt() {
+    public void testAddConfigurationComplexAt() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, null, "This..is.a.complex");
         checkAddConfig(c);
@@ -409,7 +409,7 @@ public class TestCombinedConfiguration {
      * Tests whether adding a new configuration is synchronized.
      */
     @Test
-    void testAddConfigurationSynchronized() {
+    public void testAddConfigurationSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         config.addConfiguration(new BaseHierarchicalConfiguration());
         sync.verify(Methods.BEGIN_WRITE, Methods.END_WRITE);
@@ -420,7 +420,7 @@ public class TestCombinedConfiguration {
      * Tests adding a configuration with a name.
      */
     @Test
-    void testAddConfigurationWithName() {
+    public void testAddConfigurationWithName() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, TEST_NAME);
         checkAddConfig(c);
@@ -438,7 +438,7 @@ public class TestCombinedConfiguration {
      * Tests adding a configuration with a name when this name already exists. This should cause an exception.
      */
     @Test
-    void testAddConfigurationWithNameTwice() {
+    public void testAddConfigurationWithNameTwice() {
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME);
         final Configuration configuration = setUpTestConfiguration();
         assertThrows(ConfigurationRuntimeException.class, () -> config.addConfiguration(configuration, TEST_NAME, "prefix"));
@@ -448,7 +448,7 @@ public class TestCombinedConfiguration {
      * Tests adding a null configuration. This should cause an exception to be thrown.
      */
     @Test
-    void testAddNullConfiguration() {
+    public void testAddNullConfiguration() {
         assertThrows(IllegalArgumentException.class, () -> config.addConfiguration(null));
     }
 
@@ -456,7 +456,7 @@ public class TestCombinedConfiguration {
      * Tests clearing a combined configuration. This should remove all contained configurations.
      */
     @Test
-    void testClear() {
+    public void testClear() {
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME, "test");
         config.addConfiguration(setUpTestConfiguration());
 
@@ -473,7 +473,7 @@ public class TestCombinedConfiguration {
      * operation. This test is related to CONFIGURATION-572.
      */
     @Test
-    void testClearRemoveChildListener() {
+    public void testClearRemoveChildListener() {
         final AbstractConfiguration child = setUpTestConfiguration();
         config.addConfiguration(child);
 
@@ -487,7 +487,7 @@ public class TestCombinedConfiguration {
      * Tests cloning a combined configuration.
      */
     @Test
-    void testClone() {
+    public void testClone() {
         config.addConfiguration(setUpTestConfiguration());
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME, "conf2");
         config.addConfiguration(new PropertiesConfiguration(), "props");
@@ -513,7 +513,7 @@ public class TestCombinedConfiguration {
      * Tests if the cloned configuration is decoupled from the original.
      */
     @Test
-    void testCloneModify() {
+    public void testCloneModify() {
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME);
         final CombinedConfiguration cc2 = (CombinedConfiguration) config.clone();
         assertTrue(cc2.getConfigurationNames().contains(TEST_NAME));
@@ -525,7 +525,7 @@ public class TestCombinedConfiguration {
      * Tests whether cloning of a configuration is correctly synchronized.
      */
     @Test
-    void testCloneSynchronized() {
+    public void testCloneSynchronized() {
         setUpSourceTest();
         config.lock(LockMode.READ); // Causes the root node to be constructed
         config.unlock(LockMode.READ);
@@ -542,7 +542,7 @@ public class TestCombinedConfiguration {
      * CONFIGURATION-445.
      */
     @Test
-    void testCombinedCopyToXML() throws ConfigurationException {
+    public void testCombinedCopyToXML() throws ConfigurationException {
         final XMLConfiguration x1 = new XMLConfiguration();
         x1.addProperty("key1", "value1");
         x1.addProperty("key1[@override]", "USER1");
@@ -571,7 +571,7 @@ public class TestCombinedConfiguration {
      * writer thread. It is checked that no inconsistencies occur.
      */
     @Test
-    void testConcurrentAccess() throws ConfigurationException, InterruptedException {
+    public void testConcurrentAccess() throws ConfigurationException, InterruptedException {
         // populate the test combined configuration
         setUpSourceTest();
         final XMLConfiguration xmlConf = new XMLConfiguration();
@@ -619,7 +619,7 @@ public class TestCombinedConfiguration {
      * Tests whether sub configurations can be created from a key.
      */
     @Test
-    void testConfigurationsAt() {
+    public void testConfigurationsAt() {
         checkConfigurationsAt(false);
     }
 
@@ -627,7 +627,7 @@ public class TestCombinedConfiguration {
      * Tests whether sub configurations can be created which are attached.
      */
     @Test
-    void testConfigurationsAtWithUpdates() {
+    public void testConfigurationsAtWithUpdates() {
         checkConfigurationsAt(true);
     }
 
@@ -636,7 +636,7 @@ public class TestCombinedConfiguration {
      * CONFIGURATION-336.
      */
     @Test
-    void testConversionExpressionEngine() {
+    public void testConversionExpressionEngine() {
         final PropertiesConfiguration child = new PropertiesConfiguration();
         child.setListDelimiterHandler(new DefaultListDelimiterHandler(','));
         child.addProperty("test(a)", "1,2,3");
@@ -656,7 +656,7 @@ public class TestCombinedConfiguration {
      * Tests whether escaped list delimiters are treated correctly.
      */
     @Test
-    void testEscapeListDelimiters() {
+    public void testEscapeListDelimiters() {
         final PropertiesConfiguration sub = new PropertiesConfiguration();
         sub.setListDelimiterHandler(new DefaultListDelimiterHandler(','));
         sub.addProperty("test.pi", "3\\,1415");
@@ -668,7 +668,7 @@ public class TestCombinedConfiguration {
      * Tests whether access to a configuration by index is correctly synchronized.
      */
     @Test
-    void testGetConfigurationByIdxSynchronized() {
+    public void testGetConfigurationByIdxSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertNotNull(config.getConfiguration(0));
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -679,7 +679,7 @@ public class TestCombinedConfiguration {
      * Tests whether access to a configuration by name is correctly synchronized.
      */
     @Test
-    void testGetConfigurationByNameSynchronized() {
+    public void testGetConfigurationByNameSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertNotNull(config.getConfiguration(CHILD1));
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -687,7 +687,7 @@ public class TestCombinedConfiguration {
     }
 
     @Test
-    void testGetConfigurationNameList() throws Exception {
+    public void testGetConfigurationNameList() throws Exception {
         config.addConfiguration(setUpTestConfiguration());
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME, "conf2");
         final AbstractConfiguration pc = new PropertiesConfiguration();
@@ -704,7 +704,7 @@ public class TestCombinedConfiguration {
      * Tests whether querying the name list of child configurations is synchronized.
      */
     @Test
-    void testGetConfigurationNameListSynchronized() {
+    public void testGetConfigurationNameListSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertFalse(config.getConfigurationNameList().isEmpty());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -715,7 +715,7 @@ public class TestCombinedConfiguration {
      * Tests whether querying the name set of child configurations is synchronized.
      */
     @Test
-    void testGetConfigurationNamesSynchronized() {
+    public void testGetConfigurationNamesSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertFalse(config.getConfigurationNames().isEmpty());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -723,7 +723,7 @@ public class TestCombinedConfiguration {
     }
 
     @Test
-    void testGetConfigurations() throws Exception {
+    public void testGetConfigurations() throws Exception {
         config.addConfiguration(setUpTestConfiguration());
         config.addConfiguration(setUpTestConfiguration(), TEST_NAME, "conf2");
         final AbstractConfiguration pc = new PropertiesConfiguration();
@@ -739,7 +739,7 @@ public class TestCombinedConfiguration {
      * Tests whether querying the list of child configurations is synchronized.
      */
     @Test
-    void testGetConfigurationsSynchronized() {
+    public void testGetConfigurationsSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertFalse(config.getConfigurations().isEmpty());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -750,7 +750,7 @@ public class TestCombinedConfiguration {
      * Tests whether read access to the conversion expression engine is synchronized.
      */
     @Test
-    void testGetConversionExpressionEngineSynchronized() {
+    public void testGetConversionExpressionEngineSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertNull(config.getConversionExpressionEngine());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -761,7 +761,7 @@ public class TestCombinedConfiguration {
      * Tests CONFIGURATION-799.
      */
     @Test
-    void testGetKeys() {
+    public void testGetKeys() {
         // Set up
         final BaseConfiguration conf1 = new BaseConfiguration();
         final String key = "x1";
@@ -782,7 +782,7 @@ public class TestCombinedConfiguration {
      * Tests whether getNodeCombiner() is correctly synchronized.
      */
     @Test
-    void testGetNodeCombinerSynchronized() {
+    public void testGetNodeCombinerSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertNotNull(config.getNodeCombiner());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -793,7 +793,7 @@ public class TestCombinedConfiguration {
      * Tests whether querying the number of child configurations is synchronized.
      */
     @Test
-    void testGetNumberOfConfigurationsSynchronized() {
+    public void testGetNumberOfConfigurationsSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertEquals(2, config.getNumberOfConfigurations());
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
@@ -804,7 +804,7 @@ public class TestCombinedConfiguration {
      * Tests the getSource() method when the passed in key belongs to the combined configuration itself.
      */
     @Test
-    void testGetSourceCombined() {
+    public void testGetSourceCombined() {
         setUpSourceTest();
         final String key = "yet.another.key";
         config.addProperty(key, Boolean.TRUE);
@@ -815,7 +815,7 @@ public class TestCombinedConfiguration {
      * Tests the gestSource() method when the source property is defined in a hierarchical configuration.
      */
     @Test
-    void testGetSourceHierarchical() {
+    public void testGetSourceHierarchical() {
         setUpSourceTest();
         assertEquals(config.getConfiguration(CHILD1), config.getSource(TEST_KEY));
     }
@@ -825,7 +825,7 @@ public class TestCombinedConfiguration {
      * source configuration.
      */
     @Test
-    void testGetSourceMulti() {
+    public void testGetSourceMulti() {
         setUpSourceTest();
         final String key = "list.key";
         config.getConfiguration(CHILD1).addProperty(key, "1,2,3");
@@ -837,7 +837,7 @@ public class TestCombinedConfiguration {
      * should cause an exception.
      */
     @Test
-    void testGetSourceMultiSources() {
+    public void testGetSourceMultiSources() {
         setUpSourceTest();
         final String key = "list.key";
         config.getConfiguration(CHILD1).addProperty(key, "1,2,3");
@@ -849,7 +849,7 @@ public class TestCombinedConfiguration {
      * Tests whether the source configuration can be detected for non hierarchical configurations.
      */
     @Test
-    void testGetSourceNonHierarchical() {
+    public void testGetSourceNonHierarchical() {
         setUpSourceTest();
         assertEquals(config.getConfiguration(CHILD2), config.getSource("another.key"));
     }
@@ -858,7 +858,7 @@ public class TestCombinedConfiguration {
      * Tests the getSource() method when a null key is passed in. This should cause an exception.
      */
     @Test
-    void testGetSourceNull() {
+    public void testGetSourceNull() {
         assertThrows(IllegalArgumentException.class, () -> config.getSource(null));
     }
 
@@ -866,7 +866,7 @@ public class TestCombinedConfiguration {
      * Tests whether multiple sources of a key can be retrieved.
      */
     @Test
-    void testGetSourcesMultiSources() {
+    public void testGetSourcesMultiSources() {
         setUpSourceTest();
         final String key = "list.key";
         config.getConfiguration(CHILD1).addProperty(key, "1,2,3");
@@ -881,7 +881,7 @@ public class TestCombinedConfiguration {
      * Tests getSources() for a non existing key.
      */
     @Test
-    void testGetSourcesUnknownKey() {
+    public void testGetSourcesUnknownKey() {
         setUpSourceTest();
         assertTrue(config.getSources("non.existing,key").isEmpty());
     }
@@ -890,7 +890,7 @@ public class TestCombinedConfiguration {
      * Tests whether getSource() is correctly synchronized.
      */
     @Test
-    void testGetSourceSynchronized() {
+    public void testGetSourceSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         assertNotNull(config.getSource(TEST_KEY));
         sync.verifyStart(Methods.BEGIN_READ);
@@ -901,7 +901,7 @@ public class TestCombinedConfiguration {
      * Tests the getSource() method when the passed in key is not contained. Result should be null in this case.
      */
     @Test
-    void testGetSourceUnknown() {
+    public void testGetSourceUnknown() {
         setUpSourceTest();
         assertNull(config.getSource("an.unknown.key"));
     }
@@ -910,7 +910,7 @@ public class TestCombinedConfiguration {
      * Tests getSource() if a child configuration is again a combined configuration.
      */
     @Test
-    void testGetSourceWithCombinedChildConfiguration() {
+    public void testGetSourceWithCombinedChildConfiguration() {
         setUpSourceTest();
         final CombinedConfiguration cc = new CombinedConfiguration();
         cc.addConfiguration(config);
@@ -921,7 +921,7 @@ public class TestCombinedConfiguration {
      * Tests accessing a newly created combined configuration.
      */
     @Test
-    void testInit() {
+    public void testInit() {
         assertEquals(0, config.getNumberOfConfigurations());
         assertTrue(config.getConfigurationNames().isEmpty());
         assertInstanceOf(UnionCombiner.class, config.getNodeCombiner());
@@ -932,7 +932,7 @@ public class TestCombinedConfiguration {
      * Tests whether only a single invalidate event is fired for a change. This test is related to CONFIGURATION-315.
      */
     @Test
-    void testInvalidateEventBeforeAndAfterChange() {
+    public void testInvalidateEventBeforeAndAfterChange() {
         ConfigurationEvent event = new ConfigurationEvent(config, ConfigurationEvent.ANY, null, null, true);
         config.onEvent(event);
         assertEquals(1, listener.invalidateEvents);
@@ -945,7 +945,7 @@ public class TestCombinedConfiguration {
      * Tests whether invalidate() performs correct synchronization.
      */
     @Test
-    void testInvalidateSynchronized() {
+    public void testInvalidateSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         config.invalidate();
         sync.verify(Methods.BEGIN_WRITE, Methods.END_WRITE);
@@ -955,7 +955,7 @@ public class TestCombinedConfiguration {
      * Tests whether requested locks are freed correctly if an exception occurs while constructing the root node.
      */
     @Test
-    void testLockHandlingWithExceptionWhenConstructingRootNode() {
+    public void testLockHandlingWithExceptionWhenConstructingRootNode() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         final RuntimeException testEx = new ConfigurationRuntimeException("Test exception");
         final BaseHierarchicalConfiguration childEx = new BaseHierarchicalConfiguration() {
@@ -975,7 +975,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration.
      */
     @Test
-    void testRemoveConfiguration() {
+    public void testRemoveConfiguration() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c);
         checkAddConfig(c);
@@ -987,7 +987,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration by index.
      */
     @Test
-    void testRemoveConfigurationAt() {
+    public void testRemoveConfigurationAt() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c);
         assertSame(c, config.removeConfigurationAt(0));
@@ -998,7 +998,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration by name.
      */
     @Test
-    void testRemoveConfigurationByName() {
+    public void testRemoveConfigurationByName() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, TEST_NAME);
         assertSame(c, config.removeConfiguration(TEST_NAME));
@@ -1009,7 +1009,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration by name, which is not contained.
      */
     @Test
-    void testRemoveConfigurationByUnknownName() {
+    public void testRemoveConfigurationByUnknownName() {
         assertNull(config.removeConfiguration("unknownName"));
         listener.checkEvent(0, 0);
     }
@@ -1018,7 +1018,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration with a name.
      */
     @Test
-    void testRemoveNamedConfiguration() {
+    public void testRemoveNamedConfiguration() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, TEST_NAME);
         config.removeConfiguration(c);
@@ -1029,7 +1029,7 @@ public class TestCombinedConfiguration {
      * Tests removing a named configuration by index.
      */
     @Test
-    void testRemoveNamedConfigurationAt() {
+    public void testRemoveNamedConfigurationAt() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c, TEST_NAME);
         assertSame(c, config.removeConfigurationAt(0));
@@ -1040,7 +1040,7 @@ public class TestCombinedConfiguration {
      * Tests removing a configuration that was not added prior.
      */
     @Test
-    void testRemoveNonContainedConfiguration() {
+    public void testRemoveNonContainedConfiguration() {
         assertFalse(config.removeConfiguration(setUpTestConfiguration()));
         listener.checkEvent(0, 0);
     }
@@ -1049,7 +1049,7 @@ public class TestCombinedConfiguration {
      * Tests whether write access to the conversion expression engine is synchronized.
      */
     @Test
-    void testSetConversionExpressionEngineSynchronized() {
+    public void testSetConversionExpressionEngineSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         config.setConversionExpressionEngine(new DefaultExpressionEngine(DefaultExpressionEngineSymbols.DEFAULT_SYMBOLS));
         sync.verify(Methods.BEGIN_WRITE, Methods.END_WRITE);
@@ -1060,7 +1060,7 @@ public class TestCombinedConfiguration {
      * Tests if setting a node combiner causes an invalidation.
      */
     @Test
-    void testSetNodeCombiner() {
+    public void testSetNodeCombiner() {
         final NodeCombiner combiner = new UnionCombiner();
         config.setNodeCombiner(combiner);
         assertSame(combiner, config.getNodeCombiner());
@@ -1071,7 +1071,7 @@ public class TestCombinedConfiguration {
      * Tests whether setNodeCombiner() is correctly synchronized.
      */
     @Test
-    void testSetNodeCombinerSynchronized() {
+    public void testSetNodeCombinerSynchronized() {
         final SynchronizerTestImpl sync = setUpSynchronizerTest();
         config.setNodeCombiner(new UnionCombiner());
         sync.verify(Methods.BEGIN_WRITE, Methods.END_WRITE);
@@ -1082,7 +1082,7 @@ public class TestCombinedConfiguration {
      * Tests setting a null node combiner. This should cause an exception.
      */
     @Test
-    void testSetNullNodeCombiner() {
+    public void testSetNullNodeCombiner() {
         assertThrows(IllegalArgumentException.class, () -> config.setNodeCombiner(null));
     }
 
@@ -1090,7 +1090,7 @@ public class TestCombinedConfiguration {
      * Tests whether a sub configuration survives updates of its parent.
      */
     @Test
-    void testSubConfigurationWithUpdates() {
+    public void testSubConfigurationWithUpdates() {
         final AbstractConfiguration srcConfig = setUpSubConfigTest();
         final HierarchicalConfiguration<ImmutableNode> sub = config.configurationAt(SUB_KEY, true);
         assertTrue(sub.getBoolean(TEST_KEY));
@@ -1103,7 +1103,7 @@ public class TestCombinedConfiguration {
      * Tests if an update of a contained configuration leeds to an invalidation of the combined configuration.
      */
     @Test
-    void testUpdateContainedConfiguration() {
+    public void testUpdateContainedConfiguration() {
         final AbstractConfiguration c = setUpTestConfiguration();
         config.addConfiguration(c);
         c.addProperty("test.otherTest", "yes");
